@@ -27,98 +27,36 @@ Torrent._ErrTrackerWarning     = 1;
 Torrent._ErrTrackerError       = 2;
 Torrent._ErrLocalError         = 3;
 
-Torrent._StaticFields = [ 'addedDate', 'announceURL', 'comment', 'creator',
-    'dateCreated', 'hashString', 'id', 'isPrivate', 'name', 'totalSize' ]
+Torrent._TrackerInactive         = 0;
+Torrent._TrackerWaiting          = 1;
+Torrent._TrackerQueued           = 2;
+Torrent._TrackerActive           = 3;
+
+
+Torrent._StaticFields = [ 'hashString', 'id' ]
+
+Torrent._MetaDataFields = [ 'addedDate', 'comment', 'creator', 'dateCreated',
+		'isPrivate', 'name', 'totalSize', 'pieceCount', 'pieceSize' ]
+
 Torrent._DynamicFields = [ 'downloadedEver', 'error', 'errorString', 'eta',
-    'haveUnchecked', 'haveValid', 'leechers', 'leftUntilDone', 'peersConnected',
-    'peersGettingFromUs', 'peersSendingToUs', 'rateDownload', 'rateUpload',
-    'recheckProgress', 'seeders', 'sizeWhenDone', 'status', 'swarmSpeed',
-    'uploadedEver', 'uploadRatio', 'seedRatioLimit', 'seedRatioMode', 'downloadDir' ]
+    'haveUnchecked', 'haveValid', 'leftUntilDone', 'metadataPercentComplete', 'peers',
+    'peersConnected', 'peersGettingFromUs', 'peersSendingToUs', 'rateDownload', 'rateUpload',
+    'recheckProgress', 'sizeWhenDone', 'status', 'trackerStats', 'desiredAvailable',
+    'uploadedEver', 'uploadRatio', 'seedRatioLimit', 'seedRatioMode', 'downloadDir', 'isFinished' ]
 
 Torrent.prototype =
 {
-	/*
-	 * Constructor
-	 */
-	initialize: function( transferListParent, fileListParent, controller, data) {
-		this._id            = data.id;
-		this._is_private    = data.isPrivate;
-		this._hashString    = data.hashString;
+	initMetaData: function( data ) {
 		this._date          = data.addedDate;
-		this._size          = data.totalSize;
-		this._tracker       = data.announceURL;
 		this._comment       = data.comment;
 		this._creator       = data.creator;
 		this._creator_date  = data.dateCreated;
-		this._sizeWhenDone  = data.sizeWhenDone;
+		this._is_private    = data.isPrivate;
 		this._name          = data.name;
 		this._name_lc       = this._name.toLowerCase( );
-		this._file_model    = [ ];
-		this._file_view     = [ ];
-
-		// Create a new <li> element
-		var top_e = document.createElement( 'li' );
-		top_e.className = 'torrent';
-		top_e.id = 'torrent_' + data.id;
-		top_e._torrent = this;
-		var element = $(top_e);
-		element._torrent = this;
-		this._element = element;
-		this._controller = controller;
-		controller._rows.push( element );
-		
-		// Create the 'name' <div>
-		var e = document.createElement( 'div' );
-		e.className = 'torrent_name';
-		top_e.appendChild( e );
-		element._name_container = e;
-		
-		// Create the 'progress details' <div>
-		e = document.createElement( 'div' );
-		e.className = 'torrent_progress_details';
-		top_e.appendChild( e );
-		element._progress_details_container = e;
-
-		// Create the 'in progress' bar
-		e = document.createElement( 'div' );
-		e.className = 'torrent_progress_bar incomplete';
-		e.style.width = '0%';
-		top_e.appendChild( e );
-		element._progress_complete_container = e;
-			
-		// Create the 'incomplete' bar (initially hidden)
-		e = document.createElement( 'div' );
-		e.className = 'torrent_progress_bar incomplete';
-		e.style.display = 'none';
-		top_e.appendChild( e );
-		element._progress_incomplete_container = e;
-		
-		// Add the pause/resume button - don't specify the
-		// image or alt text until the 'refresh()' function
-		// (depends on torrent state)
-		var image = document.createElement( 'div' );
-		image.className = 'torrent_pause';
-		e = document.createElement( 'a' );
-		e.appendChild( image );
-		top_e.appendChild( e );
-		element._pause_resume_button_image = image;
-		if (!iPhone) $(e).bind('click', function(e) { element._torrent.clickPauseResumeButton(e); });
-		
-		// Create the 'peer details' <div>
-		e = document.createElement( 'div' );
-		e.className = 'torrent_peer_details';
-		top_e.appendChild( e );
-		element._peer_details_container = e;
-		
-		// Set the torrent click observer
-		element.bind('click', function(e){ element._torrent.clickTorrent(e) });
-		
-		// Safari hack - first torrent needs to be moved down for some reason. Seems to be ok when
-		// using <li>'s in straight html, but adding through the DOM gets a bit odd.
-		if ($.browser.safari)
-			this._element.css('margin-top', '7px');
-
-		this.initializeTorrentFilesInspectorGroup( fileListParent );
+		this._size          = data.totalSize;
+		this._pieceCount    = data.pieceCount;
+		this._pieceSize     = data.pieceSize;
 
 		if( data.files ) {
 			for( var i=0, row; row=data.files[i]; ++i ) {
@@ -130,14 +68,101 @@ Torrent.prototype =
 				};
 			}
 		}
+	},
+
+	/*
+	 * Constructor
+	 */
+	initialize: function( transferListParent, fileListParent, controller, data) {
+		this._id            = data.id;
+		this._hashString    = data.hashString;
+		this._sizeWhenDone  = data.sizeWhenDone;
+		this._trackerStats  = this.buildTrackerStats(data.trackerStats);
+		this._file_model    = [ ];
+		this._file_view     = [ ];
+		this.initMetaData( data );
+
+		// Create a new <li> element
+		var top_e = document.createElement( 'li' );
+		top_e.className = 'torrent';
+		top_e.id = 'torrent_' + data.id;
+		top_e._torrent = this;
+		var element = $(top_e);
+		$(element).bind('dblclick', function(e) { transmission.toggleInspector(); });
+		element._torrent = this;
+		element._id = this._id;
+		this._element = element;
+		this._controller = controller;
+		controller._rows.push( element );
+
+		// Create the 'name' <div>
+		var e = document.createElement( 'div' );
+		e.className = 'torrent_name';
+		top_e.appendChild( e );
+		element._name_container = e;
+
+		// Create the 'peer details' <div>
+		e = document.createElement( 'div' );
+		e.className = 'torrent_peer_details';
+		top_e.appendChild( e );
+		element._peer_details_container = e;
+
+		//Create a progress bar container
+		top_a = document.createElement( 'div' );
+		top_a.className = 'torrent_progress_bar_container';
+		element._progress_bar_container = top_a;
+
+		// Create the 'in progress' bar
+		e = document.createElement( 'div' );
+		e.className = 'torrent_progress_bar incomplete';
+		e.style.width = '0%';
+		top_a.appendChild( e );
+		element._progress_complete_container = e;
+
+		// Create the 'incomplete' bar (initially hidden)
+		e = document.createElement( 'div' );
+		e.className = 'torrent_progress_bar incomplete';
+		e.style.display = 'none';
+		top_a.appendChild( e );
+		element._progress_incomplete_container = e;
+
+		//Add the progress bar container to the torrent
+		top_e.appendChild(top_a);
+
+		// Add the pause/resume button - don't specify the
+		// image or alt text until the 'refresh()' function
+		// (depends on torrent state)
+		var image = document.createElement( 'div' );
+		image.className = 'torrent_pause';
+		e = document.createElement( 'a' );
+		e.appendChild( image );
+		top_e.appendChild( e );
+		element._pause_resume_button_image = image;
+		if (!iPhone) $(e).bind('click', function(e) { element._torrent.clickPauseResumeButton(e); });
+
+		// Create the 'progress details' <div>
+		e = document.createElement( 'div' );
+		e.className = 'torrent_progress_details';
+		top_e.appendChild( e );
+		element._progress_details_container = e;
+
+		// Set the torrent click observer
+		element.bind('click', function(e){ element._torrent.clickTorrent(e) });
+
+		// Safari hack - first torrent needs to be moved down for some reason. Seems to be ok when
+		// using <li>'s in straight html, but adding through the DOM gets a bit odd.
+		if ($.browser.safari)
+			this._element.css('margin-top', '7px');
+
+		this.initializeTorrentFilesInspectorGroup( fileListParent );
 
 		// Update all the labels etc
 		this.refresh(data);
-		
+
 		// insert the element
 		transferListParent.appendChild(top_e);
 	},
-	
+
 	initializeTorrentFilesInspectorGroup: function( fileListParent ) {
 		var e = document.createElement( 'ul' );
 		e.className = 'inspector_torrent_file_list inspector_group';
@@ -145,17 +170,45 @@ Torrent.prototype =
 		fileListParent.appendChild( e );
 		this._fileList = e;
 	},
-	
+
 	fileList: function() {
 		return $(this._fileList);
 	},
-	
+
+	buildTrackerStats: function(trackerStats) {
+		result = [];
+		for( var i=0, tracker; tracker=trackerStats[i]; ++i ) {
+			tier = result[tracker.tier] || [];
+			tier[tier.length] = {
+				'host': tracker.host,
+				'announce': tracker.announce,
+				'hasAnnounced': tracker.hasAnnounced,
+				'lastAnnounceTime': tracker.lastAnnounceTime,
+				'lastAnnounceSucceeded': tracker.lastAnnounceSucceeded,
+				'lastAnnounceResult': tracker.lastAnnounceResult,
+				'lastAnnouncePeerCount': tracker.lastAnnouncePeerCount,
+				'announceState': tracker.announceState,
+				'nextAnnounceTime': tracker.nextAnnounceTime,
+				'isBackup': tracker.isBackup,
+				'hasScraped': tracker.hasScraped,
+				'lastScrapeTime': tracker.lastScrapeTime,
+				'lastScrapeSucceeded': tracker.lastScrapeSucceeded,
+				'lastScrapeResult': tracker.lastScrapeResult,
+				'seederCount': tracker.seederCount,
+				'leecherCount': tracker.leecherCount,
+				'downloadCount': tracker.downloadCount
+			};
+			result[tracker.tier] = tier;
+		}
+		return result;
+	},
+
 	/*--------------------------------------------
 	 *
 	 *  S E T T E R S   /   G E T T E R S
 	 *
 	 *--------------------------------------------*/
-	
+
 	/* Return the DOM element for this torrent (a <LI> element) */
 	element: function() {
 		return this._element;
@@ -177,20 +230,24 @@ Torrent.prototype =
 	downloadTotal: function() { return this._download_total; },
 	hash: function() { return this._hashString; },
 	id: function() { return this._id; },
+	isActiveFilter: function() { return this.peersGettingFromUs() > 0
+					|| this.peersSendingToUs() > 0
+					|| this.state() == Torrent._StatusChecking; },
 	isActive: function() { return this.state() != Torrent._StatusPaused; },
 	isDownloading: function() { return this.state() == Torrent._StatusDownloading; },
+	isFinished: function() { return this._isFinishedSeeding; },
 	isSeeding: function() { return this.state() == Torrent._StatusSeeding; },
 	name: function() { return this._name; },
 	peersSendingToUs: function() { return this._peers_sending_to_us; },
 	peersGettingFromUs: function() { return this._peers_getting_from_us; },
+	needsMetaData: function(){ return this._metadataPercentComplete < 1 },
 	getPercentDone: function() {
 		if( !this._sizeWhenDone ) return 1.0;
 		if( !this._leftUntilDone ) return 1.0;
 		return ( this._sizeWhenDone - this._leftUntilDone ) / this._sizeWhenDone;
 	},
 	getPercentDoneStr: function() {
-		return Math.floor(100 * Math.ratio( 100 * ( this._sizeWhenDone - this._leftUntilDone ),
-		                           this._sizeWhenDone )) / 100;
+		return Transmission.fmt.percentString( 100 * this.getPercentDone() );
 	},
 	size: function() { return this._size; },
 	state: function() { return this._state; },
@@ -198,15 +255,13 @@ Torrent.prototype =
 		switch( this.state() ) {
 			case Torrent._StatusSeeding:        return 'Seeding';
 			case Torrent._StatusDownloading:    return 'Downloading';
-			case Torrent._StatusPaused:         return 'Paused';
+			case Torrent._StatusPaused:         return this.isFinished() ? 'Seeding complete' : 'Paused';
 			case Torrent._StatusChecking:       return 'Verifying local data';
 			case Torrent._StatusWaitingToCheck: return 'Waiting to verify';
 			default:                            return 'error';
 		}
 	},
-	swarmSpeed: function() { return this._swarm_speed; },
-	totalLeechers: function() { return this._total_leechers; },
-	totalSeeders: function() { return this._total_seeders; },
+	trackerStats: function() { return this._trackerStats; },
 	uploadSpeed: function() { return this._upload_speed; },
 	uploadTotal: function() { return this._upload_total; },
 	showFileList: function() {
@@ -224,13 +279,13 @@ Torrent.prototype =
 			default:                      return -1;
 		}
 	},
-	
+
 	/*--------------------------------------------
 	 *
 	 *  E V E N T   F U N C T I O N S
 	 *
 	 *--------------------------------------------*/
-	
+
 	/*
 	 * Process a click event on this torrent
 	 */
@@ -239,8 +294,11 @@ Torrent.prototype =
 		// Prevents click carrying to parent element
 		// which deselects all on click
 		event.stopPropagation();
+		// but still hide the context menu if it is showing
+		$('#jqContextMenu').hide();
+
 		var torrent = this;
-		
+
 		// 'Apple' button emulation on PC :
 		// Need settable meta-key and ctrl-key variables for mac emulation
 		var meta_key = event.metaKey;
@@ -249,35 +307,35 @@ Torrent.prototype =
 			meta_key = true;
 			ctrl_key = false;
 		}
-		
+
 		// Shift-Click - Highlight a range between this torrent and the last-clicked torrent
 		if (iPhone) {
 			if ( torrent.isSelected() )
 				torrent._controller.showInspector();
 			torrent._controller.setSelectedTorrent( torrent, true );
-		
+
 		} else if (event.shiftKey) {
 			torrent._controller.selectRange( torrent, true );
 			// Need to deselect any selected text
 			window.focus();
-		
+
 		// Apple-Click, not selected
 		} else if (!torrent.isSelected() && meta_key) {
 			torrent._controller.selectTorrent( torrent, true );
-			
+
 		// Regular Click, not selected
 		} else if (!torrent.isSelected()) {
 			torrent._controller.setSelectedTorrent( torrent, true );
-		
-		// Apple-Click, selected	
+
+		// Apple-Click, selected
 		} else if (torrent.isSelected() && meta_key) {
 			torrent._controller.deselectTorrent( torrent, true );
-			
+
 		// Regular Click, selected
 		} else if (torrent.isSelected()) {
 			torrent._controller.setSelectedTorrent( torrent, true );
 		}
-		
+
 		torrent._controller.setLastTorrentClicked(torrent);
 	},
 
@@ -302,7 +360,14 @@ Torrent.prototype =
 	 *  I N T E R F A C E   F U N C T I O N S
 	 *
 	 *--------------------------------------------*/
-	
+
+	refreshMetaData: function(data) {
+		this.initMetaData( data );
+		this.ensureFileListExists();
+		this.refreshFileView();
+		this.refreshHTML( );
+	},
+
 	refresh: function(data) {
 		this.refreshData( data );
 		this.refreshHTML( );
@@ -311,30 +376,36 @@ Torrent.prototype =
 	/*
 	 * Refresh display
 	 */
-	refreshData: function(data) {
-		this._completed             = data.haveUnchecked + data.haveValid;
-		this._verified              = data.haveValid;
-		this._leftUntilDone         = data.leftUntilDone;
-		this._download_total        = data.downloadedEver;
-		this._upload_total          = data.uploadedEver;
-		this._upload_ratio          = data.uploadRatio;
-		this._seed_ratio_limit      = data.seedRatioLimit;
-		this._seed_ratio_mode       = data.seedRatioMode;
-		this._download_speed        = data.rateDownload;
-		this._upload_speed          = data.rateUpload;
-		this._peers_connected       = data.peersConnected;
-		this._peers_getting_from_us = data.peersGettingFromUs;
-		this._peers_sending_to_us   = data.peersSendingToUs;
-		this._sizeWhenDone          = data.sizeWhenDone;
-		this._recheckProgress       = data.recheckProgress;
-		this._error                 = data.error;
-		this._error_string          = data.errorString;
-		this._eta                   = data.eta;
-		this._swarm_speed           = data.swarmSpeed;
-		this._total_leechers        = Math.max( 0, data.leechers );
-		this._total_seeders         = Math.max( 0, data.seeders );
-		this._state                 = data.status;
-		this._download_dir          = data.downloadDir;
+	refreshData: function(data)
+	{
+		if( this.needsMetaData() && ( data.metadataPercentComplete >= 1 ) )
+			transmission.refreshMetaData( [ this._id ] );
+
+		this._completed               = data.haveUnchecked + data.haveValid;
+		this._verified                = data.haveValid;
+		this._leftUntilDone           = data.leftUntilDone;
+		this._download_total          = data.downloadedEver;
+		this._upload_total            = data.uploadedEver;
+		this._upload_ratio            = data.uploadRatio;
+		this._seed_ratio_limit        = data.seedRatioLimit;
+		this._seed_ratio_mode         = data.seedRatioMode;
+		this._download_speed          = data.rateDownload;
+		this._upload_speed            = data.rateUpload;
+		this._peers                   = data.peers;
+		this._peers_connected         = data.peersConnected;
+		this._peers_getting_from_us   = data.peersGettingFromUs;
+		this._peers_sending_to_us     = data.peersSendingToUs;
+		this._sizeWhenDone            = data.sizeWhenDone;
+		this._recheckProgress         = data.recheckProgress;
+		this._error                   = data.error;
+		this._error_string            = data.errorString;
+		this._eta                     = data.eta;
+		this._trackerStats            = this.buildTrackerStats(data.trackerStats);
+		this._state                   = data.status;
+		this._download_dir            = data.downloadDir;
+		this._metadataPercentComplete = data.metadataPercentComplete;
+		this._isFinishedSeeding       = data.isFinished;
+		this._desiredAvailable        = data.desiredAvailable;
 
 		if (data.fileStats)
 			this.refreshFileModel( data );
@@ -363,10 +434,18 @@ Torrent.prototype =
 		return null;
 	},
 
+	formatUL: function() {
+		return 'UL: ' + Transmission.fmt.speedBps(this._upload_speed);
+	},
+	formatDL: function() {
+		return 'DL: ' + Transmission.fmt.speedBps(this._download_speed);
+	},
+
 	getPeerDetails: function()
 	{
 		var c;
 
+		var compact_mode = this._controller[Prefs._CompactDisplayState];
 		if(( c = this.getErrorMessage( )))
 			return c;
 
@@ -379,34 +458,25 @@ Torrent.prototype =
 				break;
 
 			case Torrent._StatusDownloading:
-				// 'Downloading from 36 of 40 peers - DL: 60.2 KB/s UL: 4.3 KB/s'
-				c = 'Downloading from ';
-				c += this.peersSendingToUs();
-				c += ' of ';
-				c += this._peers_connected;
-				c += ' peers - DL: ';
-				c += Math.formatBytes(this._download_speed);
-				c += '/s UL: ';
-				c += Math.formatBytes(this._upload_speed);
-				c += '/s';
+				var a = [ ];
+				if(!compact_mode)
+					a.push( 'Downloading from', this.peersSendingToUs(), 'of', this._peers_connected, 'peers', '-' );
+				a.push( this.formatDL(), this.formatUL() );
+				c = a.join(' ');
 				break;
 
 			case Torrent._StatusSeeding:
-				// 'Seeding to 13 of 22 peers - UL: 36.2 KB/s'
-				c = 'Seeding to ';
-				c += this.peersGettingFromUs();
-				c += ' of ';
-				c += this._peers_connected;
-				c += ' peers - UL: ';
-				c += Math.formatBytes(this._upload_speed);
-				c += '/s';
+				if(compact_mode){
+					c = this.formatUL();
+				} else {
+					// 'Seeding to 13 of 22 peers - UL: 36.2 KiB/s'
+					c = [ 'Seeding to', this.peersGettingFromUs(), 'of', this._peers_connected, 'peers', '-', this.formatUL() ].join(' ');
+				}
 				break;
 
 			case Torrent._StatusChecking:
 				// 'Verifying local data (40% tested)'
-				c = 'Verifying local data (';
-				c += Math.roundWithPrecision( 100.0 * this._recheckProgress, 0 );
-				c += '% tested)';
+				c = [ 'Verifying local data (', Transmission.fmt.percentString( 100.0 * this._recheckProgress ), '% tested)' ].join('');
 				break;
 		}
 		return c;
@@ -418,9 +488,21 @@ Torrent.prototype =
 		var progress_details;
 		var root = this._element;
 		var MaxBarWidth = 100; // reduce this to make the progress bar shorter (%)
-		
+		var compact_mode = this._controller[Prefs._CompactDisplayState];
+		var compact = '';
+		if(compact_mode){
+			compact = ' compact';
+			root._peer_details_container.style.display = 'none';
+		} else {
+			root._peer_details_container.style.display = 'block';
+		}
+
+		root._progress_details_container.className = 'torrent_progress_details'+compact
+		root._progress_bar_container.className = 'torrent_progress_bar_container'+compact;
+		root._name_container.className = 'torrent_name'+compact;
+
 		setInnerHTML( root._name_container, this._name );
-		
+
 		// Add the progress bar
 		var notDone = this._leftUntilDone > 0;
 
@@ -428,63 +510,89 @@ Torrent.prototype =
 		// when a verifying/downloading torrent gets state seeding
 		if( this._state === Torrent._StatusSeeding )
 			notDone = false ;
-		
-		if( notDone )
+
+		if( this.needsMetaData() ){
+			var metaPercentComplete = this._metadataPercentComplete * 100;
+			progress_details = [ "Magnetized transfer - retrieving metadata (",
+			                     Transmission.fmt.percentString( metaPercentComplete ),
+			                     "%)" ].join('');
+
+			var empty = "";
+			if(metaPercentComplete == 0)
+				empty = "empty";
+
+			root._progress_complete_container.style.width = metaPercentComplete + "%";
+			root._progress_complete_container.className = 'torrent_progress_bar in_progress meta ' + empty+compact;
+			root._progress_incomplete_container.style.width = 100 - metaPercentComplete + "%"
+			root._progress_incomplete_container.className = 'torrent_progress_bar incomplete compact meta'+compact;
+			root._progress_incomplete_container.style.display = 'block';
+		}
+		else if( notDone )
 		{
-			var eta = '';
-			
-			if( this.isActive( ) )
-			{
-				eta = ' - ';
-				if (this._eta < 0 || this._eta >= Torrent._InfiniteTimeRemaining )
-					eta += 'remaining time unknown';
-				else
-					eta += Math.formatSeconds(this._eta) + ' remaining';
-			}
-			
 			// Create the 'progress details' label
-			// Eg: '101 MB of 631 MB (16.02%) - 2 hr remaining'
-			c = Math.formatBytes( this._sizeWhenDone - this._leftUntilDone );
-			c += ' of ';
-			c += Math.formatBytes( this._sizeWhenDone );
-			c += ' (';
-			c += this.getPercentDoneStr();
-			c += '%)';
-			c += eta;
-			progress_details = c;
-		
+			// Eg: '101 MiB of 631 MiB (16.02%) - 2 hr remaining'
+
+			c = [ Transmission.fmt.size( this._sizeWhenDone - this._leftUntilDone ),
+			      ' of ', Transmission.fmt.size( this._sizeWhenDone ),
+			      ' (', this.getPercentDoneStr(), '%)' ];
+			if( this.isActive( ) ) {
+				c.push( ' - ' );
+				if (this._eta < 0 || this._eta >= Torrent._InfiniteTimeRemaining )
+					c.push( 'remaining time unknown' );
+				else
+					c.push( Transmission.fmt.timeInterval(this._eta) + ' remaining' );
+			}
+			progress_details = c.join('');
+
 			// Figure out the percent completed
-			var css_completed_width = Math.floor( this.getPercentDone() * 100 * MaxBarWidth ) / 100;
-			
+			var css_completed_width = ( this.getPercentDone() * MaxBarWidth ).toTruncFixed( 2 );
+
 			// Update the 'in progress' bar
 			e = root._progress_complete_container;
-			c = 'torrent_progress_bar';
-			c += this.isActive() ? ' in_progress' : ' incomplete_stopped';
-			if(css_completed_width === 0) { c += ' empty'; }
-			e.className = c;
+			c = [ 'torrent_progress_bar'+compact,
+			      this.isActive() ? 'in_progress' : 'incomplete_stopped' ];
+			if(css_completed_width === 0) { c.push( 'empty' ); }
+			e.className = c.join(' ');
 			e.style.width = css_completed_width + '%';
-			
+
 			// Update the 'incomplete' bar
 			e = root._progress_incomplete_container;
-			if( e.className.indexOf( 'incomplete' ) === -1 )
-				e.className = 'torrent_progress_bar in_progress';
-			// Clear the 'seeding' tag 
-			if( e.className.indexOf( 'seeding' ) != -1 ) 
-				e.className = 'torrent_progress_bar incomplete';
+			e.className = 'torrent_progress_bar incomplete'
 			e.style.width =  (MaxBarWidth - css_completed_width) + '%';
 			e.style.display = 'block';
 		}
 		else
 		{
 			// Create the 'progress details' label
-			// Eg: '698.05 MB, uploaded 8.59 GB (Ratio: 12.3)'
-			c = Math.formatBytes( this._size );
-			c += ', uploaded ';
-			c += Math.formatBytes( this._upload_total );
-			c += ' (Ratio ';
-			c += Math.round(this._upload_ratio*100)/100;
-			c += ')';
-			progress_details = c;
+
+			if( this._size == this._sizeWhenDone )
+			{
+				// seed: '698.05 MiB'
+				c = [ Transmission.fmt.size( this._size ) ];
+			}
+			else
+			{
+				// partial seed: '127.21 MiB of 698.05 MiB (18.2%)'
+				c = [ Transmission.fmt.size( this._sizeWhenDone ), ' of ', Transmission.fmt.size( this._size ),
+				      ' (', Transmission.fmt.percentString( 100.0 * this._sizeWhenDone / this._size ), '%)' ];
+			}
+
+			// append UL stats: ', uploaded 8.59 GiB (Ratio: 12.3)'
+			c.push( ', uploaded ', Transmission.fmt.size( this._upload_total ),
+			        ' (Ratio ', Transmission.fmt.ratioString( this._upload_ratio ), ')' );
+
+			// maybe append remaining time
+			if( this.isActive( ) && this.seedRatioLimit( ) > 0 )
+			{
+				c.push(' - ');
+
+				if (this._eta < 0 || this._eta >= Torrent._InfiniteTimeRemaining )
+					c.push( 'remaining time unknown' );
+				else
+					c.push( Transmission.fmt.timeInterval(this._eta), ' remaining' );
+			}
+
+			progress_details = c.join('');
 
 			var status = this.isActive() ? 'complete' : 'complete_stopped';
 
@@ -515,23 +623,38 @@ Torrent.prototype =
 			e = root._progress_complete_container;
 			e.className = 'torrent_progress_bar ' + status;
 		}
-		
+
+		var hasError = this.getErrorMessage( ) != undefined;
 		// Update the progress details
+		if(compact_mode){
+			progress_details = this.getPeerDetails();
+			$(root._progress_details_container).toggleClass('error',hasError);
+		} else {
+			$(root._peer_details_container).toggleClass('error',hasError);
+		}
 		setInnerHTML( root._progress_details_container, progress_details );
-		
+
+		if( compact ){
+			var width = root._progress_details_container.offsetLeft - root._name_container.offsetLeft;
+			root._name_container.style.width = width + 'px';
+		}
+		else {
+			root._name_container.style.width = '100%';
+		}
+
 		// Update the peer details and pause/resume button
 		e = root._pause_resume_button_image;
 		if ( this.state() === Torrent._StatusPaused ) {
 			e.alt = 'Resume';
-			e.className = "torrent_resume";
+			e.className = "torrent_resume"+compact;
 		} else {
 			e.alt = 'Pause';
-			e.className = "torrent_pause";
+			e.className = "torrent_pause"+compact;
 		}
-		
+
 		setInnerHTML( root._peer_details_container, this.getPeerDetails( ) );
-	
-		this.refreshFileView( );	
+
+		this.refreshFileView( );
 	},
 
 	refreshFileView: function() {
@@ -575,9 +698,12 @@ Torrent.prototype =
 	test: function( filter, search )
 	{
 		var pass = false;
-		
+
 		switch( filter )
 		{
+			case Prefs._FilterActive:
+				pass = this.isActiveFilter();
+				break;
 			case Prefs._FilterSeeding:
 				pass = this.isSeeding();
 				break;
@@ -587,17 +713,20 @@ Torrent.prototype =
 			case Prefs._FilterPaused:
 				pass = !this.isActive();
 				break;
+			case Prefs._FilterFinished:
+				pass = this.isFinished();
+				break;
 			default:
 				pass = true;
 				break;
 		}
-		
+
 		if( !pass )
 			return false;
-		
+
 		if( !search || !search.length )
 			return pass;
-		
+
 		return this._name_lc.indexOf( search.toLowerCase() ) !== -1;
 	}
 };
@@ -617,11 +746,6 @@ Torrent.compareByName = function( a, b ) {
 	return a._name_lc.compareTo( b._name_lc );
 };
 
-/** Helper function for sortTorrents(). */
-Torrent.compareByTracker = function( a, b ) {
-	return a._tracker.compareTo( b._tracker );
-};
-
 /** Helper function for sortTorrents(). */
 Torrent.compareByState = function( a, b ) {
 	return a.state() - b.state();
@@ -665,9 +789,6 @@ Torrent.sortTorrents = function( torrents, sortMethod, sortDirection )
 		case Prefs._SortByState:
 			torrents.sort( this.compareByState );
 			break;
-		case Prefs._SortByTracker:
-			torrents.sort( this.compareByTracker );
-			break;
 		case Prefs._SortByName:
 			torrents.sort( this.compareByName );
 			break;
@@ -675,10 +796,10 @@ Torrent.sortTorrents = function( torrents, sortMethod, sortDirection )
 			console.warn( "unknown sort method: " + sortMethod );
 			break;
 	}
-	
+
 	if( sortDirection === Prefs._SortDescending )
 		torrents.reverse( );
-	
+
 	return torrents;
 };
 
@@ -741,7 +862,7 @@ TorrentFile.prototype = {
 		li.appendChild(pri_div);
 		li.appendChild(file_div);
 		li.appendChild(prog_div);
-		
+
 		this._element = li;
 		this._priority_control = pri_div;
 		this._progress = $(prog_div);
@@ -759,7 +880,7 @@ TorrentFile.prototype = {
 	isEditable: function () {
 		return (this._torrent._file_model.length>1) && !this.isDone();
 	},
-	
+
 	readAttributes: function(file_data) {
 		if( file_data.index !== undefined && file_data.index !== this._index ) {
 			this._index = file_data.index;
@@ -782,15 +903,15 @@ TorrentFile.prototype = {
 			this._dirty = true;
 		}
 	},
-	
+
 	element: function() {
 		return $(this._element);
 	},
-	
+
 	domElement: function() {
 		return this._element;
 	},
-	
+
 	setPriority: function(prio) {
 		if (this.isEditable()) {
 			var cmd;
@@ -804,21 +925,23 @@ TorrentFile.prototype = {
 			this._torrent._controller.changeFileCommand( cmd, this._torrent, this );
 		}
 	},
-	
-	setWanted: function(wanted) {
+
+	setWanted: function(wanted, process) {
 		this._dirty = true;
 		this._wanted = wanted;
 		if(!iPhone)
-		  this.element().toggleClass( 'skip', !wanted );
-		var command = wanted ? 'files-wanted' : 'files-unwanted';
-		this._torrent._controller.changeFileCommand(command, this._torrent, this);
+			this.element().toggleClass( 'skip', !wanted );
+		if (process) {
+			var command = wanted ? 'files-wanted' : 'files-unwanted';
+			this._torrent._controller.changeFileCommand(command, this._torrent, this);
+		}
 	},
-	
+
 	toggleWanted: function() {
 		if (this.isEditable())
-			this.setWanted( !this._wanted );
+			this.setWanted( !this._wanted, true );
 	},
-	
+
 	refreshHTML: function() {
 		if( this._dirty ) {
 			this._dirty = false;
@@ -827,40 +950,40 @@ TorrentFile.prototype = {
 			this.refreshPriorityHTML();
 		}
 	},
-	
+
 	refreshProgressHTML: function() {
-		var c = Math.formatBytes(this._done);
-		c += ' of ';
-		c += Math.formatBytes(this._size);
-		c += ' (';
-		c += Math.ratio(100 * this._done, this._size);
-		c += '%)';
+		var c = [ Transmission.fmt.size(this._done),
+		          ' of ',
+		          Transmission.fmt.size(this._size),
+		          ' (',
+		          this._size ? Transmission.fmt.percentString(100 * this._done / this._size) : '100',
+		          '%)' ].join('');
 		setInnerHTML(this._progress[0], c);
 	},
-	
+
 	refreshWantedHTML: function() {
 		var e = this.domElement();
-		var c = e.classNameConst;
-		if(!this._wanted) { c += ' skip'; }
-		if(this.isDone()) { c += ' complete'; }
-		e.className = c;
+		var c = [ e.classNameConst ];
+		if(!this._wanted) { c.push( 'skip' ); }
+		if(this.isDone()) { c.push( 'complete' ); }
+		e.className = c.join(' ');
 	},
-	
+
 	refreshPriorityHTML: function() {
 		var e = this._priority_control;
-		var c = e.classNameConst;
+		var c = [ e.classNameConst ];
 		switch( this._prio ) {
-			case 1: c += ' high'; break;
-			case -1: c += ' low'; break;
-			default: c += ' normal'; break;
+			case 1  : c.push( 'high'   ); break;
+			case -1 : c.push( 'low'    ); break;
+			default : c.push( 'normal' ); break;
 		}
-		e.className = c;
+		e.className = c.join(' ');
 	},
-	
+
 	fileWantedControlClicked: function(event) {
 		this.toggleWanted();
 	},
-	
+
 	filePriorityControlClicked: function(event, element) {
 		var x = event.pageX;
 		while (element !== null) {
